@@ -7,5 +7,6 @@ def measure_response_time(url: str) -> float:
     """
     Measure the response time of the GET request to the given URL.
     """
-    r = httpx.get(url)
-    return r.elapsed.total_seconds()
+    with httpx.Client() as c:
+        r = c.get(url)
+        return r.elapsed.total_seconds()
